@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2006 Nate Nielsen
+ * Copyright (C) 2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,7 +63,8 @@ gchar*               seahorse_ssh_operation_sync         (SeahorseSSHSource *ssr
 SeahorseOperation*   seahorse_ssh_operation_upload       (SeahorseSSHSource *ssrc,
                                                           GList *keys,
                                                           const gchar *username,
-                                                          const gchar *hostname);
+                                                          const gchar *hostname, 
+                                                          const gchar *port);
 
 /* result: the generated SeahorseKey */
 SeahorseOperation*   seahorse_ssh_operation_generate     (SeahorseSSHSource *src, 
