@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: seahorse-extension.c,v 1.6 2006/11/09 18:15:25 nnielsen Exp $
+ *  $Id: seahorse-extension.c 1729 2007-04-15 18:24:34Z sadam $
  */
 
 #include "config.h"
@@ -476,12 +476,13 @@ context_menu_cb (EphyEmbed *embed,
     is_input = mozilla_is_input (embed);
 
     if (is_input == FALSE)
-        return FALSE;
-        
-	text = mozilla_get_text (embed);
+        text = NULL;
+    else
+        text = mozilla_get_text (embed);
 	
 	if (text != NULL)
-        texttype = detect_text_type (text, -1, NULL, NULL);   
+        texttype = detect_text_type (text, -1, NULL, NULL);
+      
 
 	action = gtk_action_group_get_action (data->action_group, ENCRYPT_ACTION);
 	g_return_val_if_fail (action != NULL, FALSE);	
