@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2004 - 2005 Nate Nielsen
+ * Copyright (C) 2004 - 2005 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ close_activate (GtkWidget *widget, SeahorseWidget *swidget)
 static void
 search_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
-    seahorse_keyserver_search_show ();
+    seahorse_keyserver_search_show (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 }
 
 /* Loads key properties if a key is selected */
@@ -64,7 +64,8 @@ properties_activate (GtkWidget *widget, SeahorseWidget *swidget)
     
     /* TODO: Handle multiple types of keys here */
     if (skey != NULL && SEAHORSE_IS_PGP_KEY (skey))
-        seahorse_key_properties_new (SEAHORSE_PGP_KEY (skey));
+        seahorse_key_properties_new (SEAHORSE_PGP_KEY (skey), 
+                                     GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 }
 
 static void 
@@ -283,7 +284,8 @@ row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *arg2
     
     skey = seahorse_key_manager_store_get_key_from_path (GTK_TREE_VIEW (glade_xml_get_widget (swidget->xml, KEY_LIST)), path, NULL);
     if (skey != NULL && SEAHORSE_IS_PGP_KEY (skey))
-        seahorse_key_properties_new (SEAHORSE_PGP_KEY (skey));
+        seahorse_key_properties_new (SEAHORSE_PGP_KEY (skey),
+                                     GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 }
 
 static void
@@ -430,7 +432,7 @@ filter_keyset (SeahorseKey *skey, const gchar* search)
  * Returns the new window created.
  **/
 GtkWindow* 
-seahorse_keyserver_results_show (SeahorseOperation *op, const gchar *search)
+seahorse_keyserver_results_show (SeahorseOperation *op, GtkWindow *parent, const gchar *search)
 {
     SeahorseKeyManagerStore *skstore;
     SeahorseKeyPredicate *pred;
@@ -442,8 +444,9 @@ seahorse_keyserver_results_show (SeahorseOperation *op, const gchar *search)
     GtkActionGroup *actions;
     GtkAction *action;
     gchar *title, *t;
+    gchar *pattern;
     
-    swidget = seahorse_widget_new_allow_multiple ("keyserver-results");
+    swidget = seahorse_widget_new_allow_multiple ("keyserver-results", parent);
     g_return_val_if_fail (swidget != NULL, NULL);
     
     win = GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name));
@@ -452,11 +455,15 @@ seahorse_keyserver_results_show (SeahorseOperation *op, const gchar *search)
     g_object_set_data (G_OBJECT (swidget), "operation", op);
     seahorse_operation_watch (op, G_CALLBACK (operation_done), NULL, swidget);
     g_signal_connect (win, "destroy", G_CALLBACK (window_destroyed), swidget);
+    
+    /* Many key servers ignore spaces at the beginning and end, so we do too */
+    pattern = g_strdup (search);
+    g_strstrip (pattern);
 
     if (!search)
         title = g_strdup (_("Remote Keys"));
     else 
-        title = g_strdup_printf(_("Remote Keys Containing '%s'"), search);
+        title = g_strdup_printf(_("Remote Keys Containing '%s'"), pattern);
     gtk_window_set_title (win, title);
     g_free (title);
     
@@ -520,7 +527,7 @@ seahorse_keyserver_results_show (SeahorseOperation *op, const gchar *search)
     pred->etype = SKEY_PUBLIC;
     pred->location = SKEY_LOC_REMOTE;
     pred->custom = (SeahorseKeyPredFunc)filter_keyset;
-    pred->custom_data = t = g_utf8_casefold (search, -1);
+    pred->custom_data = t = g_utf8_casefold (pattern, -1);
   
     /* Our keyset all nicely filtered */
     skset = seahorse_keyset_new_full (pred);
@@ -534,6 +541,8 @@ seahorse_keyserver_results_show (SeahorseOperation *op, const gchar *search)
     g_object_unref (skset);
     
     selection_changed (selection, swidget);
+    
+    g_free (pattern);
 
     return win;
 }
